==> update-core-image-barix-audioplex-7.0.4.tar: usr/bin/asound-gen.sh <==
##################################################################################
#
#	asound.conf generator script
# 
#     	Board support: 
#           M400                 (54)
#           TPA400               (66)
#           USSI_ENC_CTRL	  (68)
#           MPA400		  (69)
#           MPI400               (73)
#           MPA400 (HyperSpike)  (75)
#           LOX400 (Synstreamer) (76)
#           LX400                (80)
##################################################################################

ASOUND_CONF_IN=/etc/asound.conf.in
ASOUND_CONF=/etc/asound.conf
APP_SOUND_CONF=/etc/barix/app-sound.conf
EXTRA_SOUND_CONF_DIR=/etc/barix/asound

##################################################################################

# set Barix Main softvol on top of a specific pcm:
# - analog_out
# - digital_out
set_pcm_out(){

cat >> $ASOUND_CONF <<EOF

# Master Volume Control
pcm.master_soft {
    type softvol
    slave.pcm "$1"
    control {
        name "BARIX_MAIN"
        card 0
    }
}

pcm.master1 {
    type plug
    slave.pcm "master_soft"
}

pcm.!default {
    type asym
    playback.pcm "plug:$1"
    capture.pcm "plug:dsnooper"
}

#defaults.pcm.rate_converter “samplerate_medium”

EOF
}

# set Barix Main softvol on top of downmix  
# - analog_out
# - digital_out
set_pcm_downmix(){

cat >> $ASOUND_CONF <<EOF
pcm.downmix {
    type route                                                                                                                           
    slave.pcm "$1"                                                                                                                
    ttable {                                                                                                   
       0.0 0.5                                                                                                                              
       1.0 0.5
       0.1 0.5
       1.1 0.5															      
    }
}

# Master Volume Control
pcm.master_soft {
    type softvol
    slave.pcm "downmix"
    control {
        name "BARIX_MAIN"
        card 0
    }
}

pcm.master1 {
    type plug
    slave.pcm "master_soft"
}

pcm.!default {
    type asym
    playback.pcm "downmix"
    capture.pcm "plug:dsnooper"
}

#defaults.pcm.rate_converter “samplerate_medium”

EOF

}

# set Barix Main softvol on top of multi card configuration
# multi card using digital_out and analog_out
set_both_out(){

cat >> $ASOUND_CONF <<EOF

# quad channel card containing both cards
pcm.quad {
    type multi
    slaves.a.pcm "digital_out"
    slaves.a.channels 2
    slaves.b.pcm "loopback_out"
    slaves.b.channels 2
    bindings.0 { slave a; channel 0; }
    bindings.1 { slave a; channel 1; }
    bindings.2 { slave b; channel 0; }
    bindings.3 { slave b; channel 1; }
}

# Stereo2Quad (both_out) routing device. It just takes the stereo input,
# and replicates it on the two channels of H3 Codec and I2S cards
# the last 6 chans of the i2s are not used
pcm.both_out {
    type route
    slave.pcm quad
    ttable.0.0 1
    ttable.1.1 1
    ttable.0.2 1
    ttable.1.3 1
}

EOF
     set_pcm_out "both_out"
}



#load base configuration
if [ -f $ASOUND_CONF_IN ]; then
	cat $ASOUND_CONF_IN > $ASOUND_CONF
fi

#set hw_type specific configuration
HW_TYPE=$(/usr/bin/qiba-spi-get-production-info.sh -w)

case "$HW_TYPE" in
    "66"|"68")
      set_pcm_downmix "digital_out"
      ;;

    "69"|"75")
      set_pcm_downmix "digital_out"
      ;;

    "73")
      set_pcm_downmix "analog_out"
      ;;

    "76"|"80")
      set_pcm_out "external_analog_out"
      ;;

     *)
      set_pcm_out "analog_out" 
     ;;
esac

# append APP asound specific configuration
if [ -f $APP_SOUND_CONF ]; then
	cat $APP_SOUND_CONF >> $ASOUND_CONF
fi

# append extra asound configuration provided by common recipes
if [ -d $EXTRA_SOUND_CONF_DIR ]; then
	for CONF_FILE in $(ls $EXTRA_SOUND_CONF_DIR/)*; do
		cat $EXTRA_SOUND_CONF_DIR/$CONF_FILE >> $ASOUND_CONF
	done
fi

==> update-core-image-barix-audioplex-8.0.0.tar: usr/bin/asound-gen.sh <==
##################################################################################
#
#	asound.conf generator script
# 
#     	Board support: 
#           M400                 (54)
#           TPA400               (66)
#           USSI_ENC_CTRL	  (68)
#           MPA400		  (69)
#           MPI400               (73)
#           MPA400 (HyperSpike)  (75)
#           LOX400 (Synstreamer) (76)
#           LX400                (80)
#           AHE                  (90)
##################################################################################

ASOUND_CONF_IN=/etc/asound.conf.in
ASOUND_CONF=/etc/asound.conf
APP_SOUND_CONF=/etc/barix/app-sound.conf
EXTRA_SOUND_CONF_DIR=/etc/barix/asound

##################################################################################

# set Barix Main softvol on top of a specific pcm:
# - analog_out
# - digital_out
set_pcm_out(){

cat >> $ASOUND_CONF <<EOF

# Master Volume Control
pcm.master_soft {
    type softvol
    slave.pcm "$1"
    control {
        name "BARIX_MAIN"
        card 0
    }
}

pcm.master1 {
    type plug
    slave.pcm "master_soft"
}

pcm.!default {
    type asym
    playback.pcm "plug:$1"
    capture.pcm "plug:dsnooper"
}

#defaults.pcm.rate_converter “samplerate_medium”

EOF
}

# set Barix Main softvol on top of downmix  
# - analog_out
# - digital_out
set_pcm_downmix(){

cat >> $ASOUND_CONF <<EOF
pcm.downmix {
    type route                                                                                                                           
    slave.pcm "$1"                                                                                                                
    ttable {                                                                                                   
       0.0 0.5                                                                                                                              
       1.0 0.5
       0.1 0.5
       1.1 0.5															      
    }
}

# Master Volume Control
pcm.master_soft {
    type softvol
    slave.pcm "downmix"
    control {
        name "BARIX_MAIN"
        card 0
    }
}

pcm.master1 {
    type plug
    slave.pcm "master_soft"
}

pcm.!default {
    type asym
    playback.pcm "downmix"
    capture.pcm "plug:dsnooper"
}

#defaults.pcm.rate_converter “samplerate_medium”

EOF

}

# set Barix Main softvol on top of multi card configuration
# multi card using digital_out and analog_out
set_both_out(){

cat >> $ASOUND_CONF <<EOF

# quad channel card containing both cards
pcm.quad {
    type multi
    slaves.a.pcm "digital_out"
    slaves.a.channels 2
    slaves.b.pcm "loopback_out"
    slaves.b.channels 2
    bindings.0 { slave a; channel 0; }
    bindings.1 { slave a; channel 1; }
    bindings.2 { slave b; channel 0; }
    bindings.3 { slave b; channel 1; }
}

# Stereo2Quad (both_out) routing device. It just takes the stereo input,
# and replicates it on the two channels of H3 Codec and I2S cards
# the last 6 chans of the i2s are not used
pcm.both_out {
    type route
    slave.pcm quad
    ttable.0.0 1
    ttable.1.1 1
    ttable.0.2 1
    ttable.1.3 1
}

EOF
     set_pcm_out "both_out"
}

# Use specific configuration for Barix AHE
# Codec -> analog_out_right -> BARIX_MAIN -> chan_x
# Codec -> analog_out_left  -> BARIX_MAIN2 -> intercom
set_pcm_AHE(){

cat >> $ASOUND_CONF <<EOF

# Master Volume Control
pcm.master_soft {
    type softvol
    slave.pcm "analog_out_right"
    control {
        name "BARIX_MAIN"
        card 0
    }
}

pcm.master1 {
    type plug
    slave.pcm "master_soft"
}

# Master INTERCOM_MAIN 
pcm.master2_soft {
    type softvol
    slave.pcm "analog_out_left"
    control {
       name "INTERCOM_MAIN"
       card 0
    }
}

pcm.master2 {
    type plug
    slave.pcm "master2_soft"
}

pcm.intercom1 {
        type            softvol
        slave.pcm       "master2_soft"
        control{
                name    "intercom"
                card    0
        }
}

pcm.!default {
    type asym
    playback.pcm "plug:analog_out_right"
    capture.pcm "plug:dsnooper"
}


EOF
}


#load base configuration
if [ -f $ASOUND_CONF_IN ]; then
	cat $ASOUND_CONF_IN > $ASOUND_CONF
fi

#set hw_type specific configuration
HW_TYPE=$(/usr/bin/qiba-spi-get-production-info.sh -w)

case "$HW_TYPE" in
    "66"|"68")
      set_pcm_downmix "digital_out"
      ;;

    "69"|"75")
      set_pcm_downmix "digital_out"
      ;;

    "73")
      set_pcm_downmix "analog_out"
      ;;

    "76"|"80")
      set_pcm_out "external_analog_out"
      ;;
    
    "90")
      set_pcm_AHE 
      ;;

     *)
      set_pcm_out "analog_out" 
     ;;
esac

# append APP asound specific configuration
if [ -f $APP_SOUND_CONF ]; then
	cat $APP_SOUND_CONF >> $ASOUND_CONF
fi

# append extra asound configuration provided by common recipes
if [ -d $EXTRA_SOUND_CONF_DIR ]; then
	for CONF_FILE in $(ls $EXTRA_SOUND_CONF_DIR/)*; do
		cat $EXTRA_SOUND_CONF_DIR/$CONF_FILE >> $ASOUND_CONF
	done
fi
